==> material-code-0.3.0-alpha.0.tgz: package/esm/CodeRenderer/CodeRenderer.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import clsx from 'clsx';
import { useUID } from 'react-uid';
import makeStyles from '@material-ui/core/styles/makeStyles';
import { Controlled as CodeMirror } from 'react-codemirror2';
import { useWidgetCode } from '@ui-schema/material-code/CodeProvider/CodeProvider';
const useStyles = makeStyles({
  root: {
    flex: '1 1 auto',
    marginTop: 0,
    height: '100%',
    position: 'relative',
    '& .CodeMirror': {
      position: 'absolute',
      top: 0,
      bottom: 0,
      left: 0,
      right: 0,
      height: '100%'
    }
  }
});
export const CodeRenderer = ({
  storeKeys,
  schema,
  value,
  onChange,
  valid,
  required,
  format
}) => {
  var _editor$display, _editor$display$lineD;

  const uid = useUID();
  const {
    theme,
    modes
  } = useWidgetCode();
  const [lines, setLines] = React.useState(1);
  const [editor, setEditor] = React.useState();
  const [focused, setFocused] = React.useState(false);
  const classes = useStyles();
  React.useEffect(() => {
    onChange(storeKeys, ['valid'], () => ({
      valid: valid
    }));
  }, [onChange, valid, storeKeys]);
  React.useEffect(() => {
    if (editor && editor.refresh) {
      editor.refresh();
    }
  }, [editor]);
  let height = 0;

  if (editor !== null && editor !== void 0 && (_editor$display = editor.display) !== null && _editor$display !== void 0 && (_editor$display$lineD = _editor$display.lineDiv) !== null && _editor$display$lineD !== void 0 && _editor$display$lineD.children && editor.display.lineDiv.children[0]) {
    height = editor.display.lineDiv.children[0].clientHeight;
  }

  if (editor !== null && editor !== void 0 && editor.display && editor.display.gutters && editor.display.wrapper) {
    if (schema.getIn(['view', 'bg']) !== true) {
      editor.display.gutters.style.background = 'transparent';
      editor.display.wrapper.style.background = 'transparent';
    }
  }

  const handleOnChange = React.useCallback(changedEditor => {
    setLines(changedEditor.doc.size);
  }, [setLines]);
  const handleBeforeChange = React.useCallback((editor, data, storeValue) => {
    onChange(storeKeys, ['value'], {
      type: 'update',
      updater: () => ({
        value: storeValue
      }),
      schema,
      required
    });
  }, [onChange, storeKeys, required, schema]);
  const mode = modes !== null && modes !== void 0 && modes[format] ? modes[format] : format;
  const options = React.useMemo(() => _objectSpread({
    mode: mode,
    lineNumbers: true
  }, theme ? {
    theme
  } : {}), [format, theme, mode]);
  return /*#__PURE__*/React.createElement("div", {
    style: {
      minHeight: '2rem',
      height: lines ? (lines + 1) * height + 6 : 'auto',
      position: 'relative'
    }
  }, /*#__PURE__*/React.createElement(CodeMirror, {
    className: clsx(classes.root, 'uis-' + uid, 'MuiInput-underline', focused ? 'Mui-focused' : null),
    editorDidMount: setEditor,
    value: value,
    onBeforeChange: handleBeforeChange,
    onChange: handleOnChange,
    onFocus: () => setFocused(true),
    onBlur: () => setFocused(false),
    options: options
  }));
};

==> material-code-0.4.0-alpha.0.tgz: package/esm/CodeRenderer/CodeRenderer.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React from 'react';
import clsx from 'clsx';
import { useUID } from 'react-uid';
import makeStyles from "@mui/styles/makeStyles";
import { Controlled as CodeMirror } from 'react-codemirror2';
import { useWidgetCode } from '@ui-schema/material-code/CodeProvider/CodeProvider';
const useStyles = makeStyles({
  root: {
    flex: '1 1 auto',
    marginTop: 0,
    height: '100%',
    position: 'relative',
    '& .CodeMirror': {
      position: 'absolute',
      top: 0,
      bottom: 0,
      left: 0,
      right: 0,
      height: '100%'
    }
  }
});
export const CodeRenderer = ({
  storeKeys,
  schema,
  value,
  onChange,
  valid,
  required,
  format
}) => {
  var _editor$display, _editor$display$lineD;

  const uid = useUID();
  const {
    theme,
    modes
  } = useWidgetCode();
  const [lines, setLines] = React.useState(1);
  const [editor, setEditor] = React.useState();
  const [focused, setFocused] = React.useState(false);
  const classes = useStyles();
  React.useEffect(() => {
    onChange({
      storeKeys: storeKeys,
      scopes: ['valid'],
      type: 'set',
      schema,
      required,
      data: {
        valid: valid
      }
    });
  }, [onChange, valid, storeKeys]);
  React.useEffect(() => {
    if (editor && editor.refresh) {
      editor.refresh();
    }
  }, [editor]);
  let height = 0;

  if (editor !== null && editor !== void 0 && (_editor$display = editor.display) !== null && _editor$display !== void 0 && (_editor$display$lineD = _editor$display.lineDiv) !== null && _editor$display$lineD !== void 0 && _editor$display$lineD.children && editor.display.lineDiv.children[0]) {
    height = editor.display.lineDiv.children[0].clientHeight;
  }

  if (editor !== null && editor !== void 0 && editor.display && editor.display.gutters && editor.display.wrapper) {
    if (schema.getIn(['view', 'bg']) !== true) {
      editor.display.gutters.style.background = 'transparent';
      editor.display.wrapper.style.background = 'transparent';
    }
  }

  const handleOnChange = React.useCallback(changedEditor => {
    setLines(changedEditor.doc.size);
  }, [setLines]);
  const handleBeforeChange = React.useCallback((editor, data, storeValue) => {
    onChange({
      storeKeys: storeKeys,
      scopes: ['value'],
      type: 'set',
      schema,
      required,
      data: {
        value: storeValue
      }
    });
  }, [onChange, storeKeys, required, schema]);
  const mode = modes !== null && modes !== void 0 && modes[format] ? modes[format] : format;
  const options = React.useMemo(() => _objectSpread({
    mode: mode,
    lineNumbers: true
  }, theme ? {
    theme
  } : {}), [format, theme, mode]);
  return /*#__PURE__*/React.createElement("div", {
    style: {
      minHeight: '2rem',
      height: lines ? (lines + 1) * height + 6 : 'auto',
      position: 'relative'
    }
  }, /*#__PURE__*/React.createElement(CodeMirror, {
    className: clsx(classes.root, 'uis-' + uid, 'MuiInput-underline', focused ? 'Mui-focused' : null),
    editorDidMount: setEditor,
    value: value,
    onBeforeChange: handleBeforeChange,
    onChange: handleOnChange,
    onFocus: () => setFocused(true),
    onBlur: () => setFocused(false),
    options: options
  }));
};
